==> dl.php?src=linea21_1_4.zip: linea21/languages/en/lang_scale.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage en
 * @author linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


/*	nommage des modules
 *  	*/
$lang['scale']['name']="scale";
$lang['scale']['confirm_add'] = "scale successfully added\n";
$lang['scale']['confirm_mod'] = "Scale successfully updated\n";
$lang['scale']['confirm_sup'] ="Scale successfully deleted\n";


/*	nommage rubrique module
 *  	*/
$lang['scale']['add']= "Add a new ".$lang['scale']['name'];
$lang['scale']['mod']= "Edit ".$lang['scale']['name'];
$lang['scale']['sup']= "Delete ".$lang['scale']['name'];
$lang['scale']['det']= ucfirst($lang['scale']['name']). " details";
$lang['scale']['list']= "View scales";


/*	nommage rubrique add / mod /det
 *  	*/
$lang['scale']['add_title']="Add data about the new ".$lang['scale']['name'];



/*	nommage rubrique sup
 *  	*/
$lang['scale']['sup_massd']= "Do you want to delete all sub-scales associated with this scale?";
$lang['scale']['sup_massm']= "Do you want to transfer all these sub-scales to another scale ?";
$lang['scale']['sup_transfert']= "Transfer scale";
/*	nommage élément rubrique
 *  	*/
$lang['scale']['denomination']="name";
$lang['scale']['surface']="surface";
$lang['scale']['population']="population";
$lang['scale']['root']="parent scale";
$lang['scale']['comment']="Comment linked with this ".$lang['scale']['name'];


/*	nommage quickbox
 *  	*/
$lang['scale']['qb_titleadd']=" latest additions";
$lang['scale']['qb_titlemod']=" latest modifications";
$lang['scale']['qb_titlesup']=" last deletes";


/*	divers
 *  	*/
$lang['scale']['select_choice']="~~ Choose in this list ~~";


/*	messages
 *  	*/
$lang['scale']['object_notdenomination']="Name is required";
$lang['scale']['object_notnumsurface']="Area must be numerical";
$lang['scale']['object_notnuminhabitants']="Population must be an integer";
$lang['scale']['object_notroot']="Parent scale is required";
$lang['scale']['sup_nomethod']="Deletion method is required";
$lang['scale']['sup_noscale']="Transfer scale is required";
$lang['scale']['sup_scale_info1']="Caution, scale transfer will include dependency tansfer of subscales, news, publications and indicators associated with!";
$lang['scale']['sup_scale_info2']="Caution, scale deletion will also remove subscales, projetcs, news, publications and indicators associated with!";


/*	rubrique d'aide
 *  	*/
$lang['scale']['help_add1']="To add a new scale, please insert the required informations in the form above";
$lang['scale']['help_add2']="A parent scale is required";
$lang['scale']['help_add3']="After submitting the form, check your data in the summary";
$lang['scale']['help_add4']='After checking summary, click the \'review settings\' button to make changes';

$lang['scale']['help_list1']="Click on scale title to display more informations";
$lang['scale']['help_list2']="Delete this scale by clicking on the delete icon linked in";
$lang['scale']['help_list3']="Edit this scale by clicking on the edit icon linked in";
$lang['scale']['help_list4']='Click \'add a new scale\' button for adding scale';
$lang['scale']['help_list5']="To perform search on scales only, just click the 'search' link";

$lang['scale']['help_mod1']="To edit a scale, please insert the required informations in the form above";
$lang['scale']['help_mod2']="Once the form submitted, check your data in the summary";
$lang['scale']['help_mod3']="Once the summary displayed, click the \'review settings\' button if you need to make new changes";

$lang['scale']['help_det1']="Click on parent's scale title to display its parent's scale information";
$lang['scale']['help_det2']="Delete this scale by clicking on the delete icon linked in";
$lang['scale']['help_det3']="Edit this scale by clicking on the edit icon linked in";

$lang['scale']['help_sup1']="Choose a deletion method to perform the operation";
$lang['scale']['help_sup2']="For secutity reasons, please enter the required security code";
$lang['scale']['help_sup3']="Caution, scale's deletion involves changes in the whole application; this deletion is recommanded to expert only";
?>

==> dl.php?src=linea21_1_6.zip: linea21/languages/en/lang_scale.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage en
 * @author linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


/*	nommage des modules
 *  	*/
$lang['scale']['name']="scale";
$lang['scale']['confirm_add'] = "scale successfully added\n";
$lang['scale']['confirm_mod'] = "Scale successfully updated\n";
$lang['scale']['confirm_sup'] ="Scale successfully deleted\n";


/*	nommage rubrique module
 *  	*/
$lang['scale']['add']= "Add a new ".$lang['scale']['name'];
$lang['scale']['mod']= "Edit ".$lang['scale']['name'];
$lang['scale']['sup']= "Delete ".$lang['scale']['name'];
$lang['scale']['det']= ucfirst($lang['scale']['name']). " details";
$lang['scale']['list']= "View scales";


/*	nommage rubrique add / mod /det
 *  	*/
$lang['scale']['add_title']="Add data about the new ".$lang['scale']['name'];



/*	nommage rubrique sup
 *  	*/
$lang['scale']['sup_massd']= "Do you want to delete all sub-scales associated with this scale?";
$lang['scale']['sup_massm']= "Do you want to transfer all these sub-scales to another scale ?";
$lang['scale']['sup_transfert']= "Transfer scale";
/*	nommage élément rubrique
 *  	*/
$lang['scale']['denomination']="name";
$lang['scale']['surface']="surface";
$lang['scale']['population']="population";
$lang['scale']['root']="parent scale";
$lang['scale']['comment']="Comment linked with this ".$lang['scale']['name'];


/*	nommage quickbox
 *  	*/
$lang['scale']['qb_titleadd']=" latest additions";
$lang['scale']['qb_titlemod']=" latest modifications";
$lang['scale']['qb_titlesup']=" last deletes";


/*	divers
 *  	*/
$lang['scale']['select_choice']="-- Choose in this list --";


/*	messages
 *  	*/
$lang['scale']['object_notdenomination']="Name is required";
$lang['scale']['object_notnumsurface']="Area must be numerical";
$lang['scale']['object_notnuminhabitants']="Population must be an integer";
$lang['scale']['object_notroot']="Parent scale is required";
$lang['scale']['sup_nomethod']="Deletion method is required";
$lang['scale']['sup_noscale']="Transfer scale is required";
$lang['scale']['sup_scale_info1']="Caution, scale transfer will include dependency tansfer of subscales, news, publications and indicators associated with!";
$lang['scale']['sup_scale_info2']="Caution, scale deletion will also remove subscales, projetcs, news, publications and indicators associated with!";


/*	rubrique d'aide
 *  	*/
$lang['scale']['help_add1']="To add a new scale, please insert the required informations in the form above";
$lang['scale']['help_add2']="A parent scale is required";
$lang['scale']['help_add3']="After submitting the form, check your data in the summary";
$lang['scale']['help_add4']='After checking summary, click the \'review settings\' button to make changes';

$lang['scale']['help_list1']="Click on scale title to display more informations";
$lang['scale']['help_list2']="Delete this scale by clicking on the delete icon linked in";
$lang['scale']['help_list3']="Edit this scale by clicking on the edit icon linked in";
$lang['scale']['help_list4']='Click \'add a new scale\' button for adding scale';
$lang['scale']['help_list5']="To perform search on scales only, just click the 'search' link";

$lang['scale']['help_mod1']="To edit a scale, please insert the required informations in the form above";
$lang['scale']['help_mod2']="Once the form submitted, check your data in the summary";
$lang['scale']['help_mod3']="Once the summary displayed, click the \'review settings\' button if you need to make new changes";

$lang['scale']['help_det1']="Click on parent's scale title to display its parent's scale information";
$lang['scale']['help_det2']="Delete this scale by clicking on the delete icon linked in";
$lang['scale']['help_det3']="Edit this scale by clicking on the edit icon linked in";

$lang['scale']['help_sup1']="Choose a deletion method to perform the operation";
$lang['scale']['help_sup2']="For secutity reasons, please enter the required security code";
$lang['scale']['help_sup3']="Caution, scale's deletion involves changes in the whole application; this deletion is recommanded to expert only";
?>
